unit frmLogin;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, LResources, Forms, Controls, Graphics, Dialogs,
  ComCtrls, StdCtrls, ExtCtrls, Buttons, SynEdit, IniFiles, hDatabase,
  uDatabase, uAppBuild, HSRConsts;

type

  { TLoginForm }

  TLoginForm = class(TForm)
    btnCancel: TBitBtn;
    btnLogin: TBitBtn;
    GroupBox2: TGroupBox;
    Image1: TImage;
    Label24: TLabel;
    Label27: TLabel;
    Panel1: TPanel;
    txtDataSource: TEdit;
    txtHostName: TEdit;
    txtPassword: TEdit;
    txtUserName: TEdit;
    GroupBox1: TGroupBox;
    Label25: TLabel;
    Label26: TLabel;
    pcPages: TPageControl;
    pnlLogo: TPanel;
    pnlButtons: TPanel;
    rgDrivers: TRadioGroup;
    tsCredentials: TTabSheet;
    tsDrivers: TTabSheet;
    procedure btnCancelClick(Sender: TObject);
    procedure btnLoginClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure pnlLogoClick(Sender: TObject);
    procedure rgDriversClick(Sender: TObject);
    procedure tbExpandChange(Sender: TObject);
    procedure txtDataSourceChange(Sender: TObject);
    procedure txtHostNameChange(Sender: TObject);
    procedure txtPasswordChange(Sender: TObject);
    procedure txtUserNameChange(Sender: TObject);
  private
    { private declarations }
    FPath    : string;
    FIniFile : string;
  private
    procedure OnDBException(sModule,sLocation,sMessage:string);
  public
    { public declarations }
  end;

var
  LoginForm : TLoginForm;

implementation
uses
  {$ifdef RSR_DEBUG}
    frmDebug,
  {$endif}
  uStorage,frmConsole,frmException;
{ TLoginForm }

procedure OnDBConnected(SessionID:TSessionHandle); stdcall;
begin
  If frmLogin.LoginForm.Visible then begin
    frmConsole.ConsoleForm.pcPages.ActivePage:=frmConsole.ConsoleForm.tsWelcome;
    frmConsole.ConsoleForm.StatusBar.Panels[1].Text:='Connected';

    frmConsole.ConsoleForm.StatusBar.Panels[0].Text:=' Checking Database Tables...';
    frmConsole.ConsoleForm.Visible:=true;
    Application.ProcessMessages;
    uStorage.CheckSystemDatabaseTables;
    frmConsole.ConsoleForm.StatusBar.Panels[0].Text:=' Loading System Settings...';
    Application.ProcessMessages;
    frmConsole.ConsoleForm.LoadSettings;
    frmConsole.ConsoleForm.StatusBar.Panels[0].Text:=' Loading Domains...';
    Application.ProcessMessages;
    frmConsole.ConsoleForm.LoadDomains;
    frmConsole.ConsoleForm.StatusBar.Panels[0].Text:=' Loading Clusters...';
    Application.ProcessMessages;
    frmConsole.ConsoleForm.LoadClusters;
    frmConsole.ConsoleForm.StatusBar.Panels[0].Text:=' Loading Nodes...';
    Application.ProcessMessages;
    frmConsole.ConsoleForm.LoadNodes;
    frmConsole.ConsoleForm.StatusBar.Panels[0].Text:=' Loading Content Types...';
    frmConsole.ConsoleForm.LoadContentTypes;
    Application.ProcessMessages;
    {$ifdef RSR_DEBUG}
      frmConsole.ConsoleForm.StatusBar.Panels[0].Text:=' Loading Debugging Systems...';
      Application.ProcessMessages;
      if frmDebug.DebugForm=nil then
        Application.CreateForm(TDebugForm,frmDebug.DebugForm);
      frmDebug.DebugForm.Show;
    {$endif}

    frmConsole.ConsoleForm.StatusBar.Panels[0].Text:=' Welcome!';
    frmConsole.ConsoleForm.Enabled:=true;

  end;
  Screen.Cursor:=crDefault;
  frmLogin.LoginForm.Visible:=false;
end;

procedure OnDBDisconnected(SessionID:TSessionHandle); stdcall;
begin
  If frmConsole.ConsoleForm.Visible then begin
    frmConsole.ConsoleForm.StatusBar.Panels[1].Text:='Disconnected';
    frmConsole.ConsoleForm.StatusBar.Panels[0].Text:='You have been disconnected.';
    frmConsole.ConsoleForm.Display_Welcome;
    frmConsole.ConsoleForm.Enabled:=false;
    frmLogin.LoginForm.Visible:=true;
    frmLogin.LoginForm.BringToFront;
  end;
  Screen.Cursor:=crDefault;
end;

procedure TLoginForm.tbExpandChange(Sender: TObject);
begin

end;

procedure TLoginForm.txtDataSourceChange(Sender: TObject);
begin
  uStorage.Header.Schema:=txtDataSource.Text;
  uStorage.SaveINIFile;
end;

procedure TLoginForm.txtHostNameChange(Sender: TObject);
begin
  uStorage.Header.HostName:=txtHostName.Text;
  uStorage.SaveINIFile;
end;

procedure TLoginForm.txtPasswordChange(Sender: TObject);
begin
  uStorage.Header.Password:=txtPassword.Text;
  uStorage.SaveINIFile;
end;

procedure TLoginForm.txtUserNameChange(Sender: TObject);
begin
  uStorage.Header.Username:=txtUserName.Text;
  uStorage.SaveINIFile;
end;

procedure TLoginForm.btnCancelClick(Sender: TObject);
begin
  Application.Terminate;
end;

procedure TLoginForm.btnLoginClick(Sender: TObject);
begin
  Screen.Cursor:=crHourglass;
  Application.ProcessMessages;
  uDatabase.Connect(uStorage.Module.SessionID);
end;
procedure TLoginForm.FormCreate(Sender: TObject);
var
  sMode:string;
  iMode:integer;
begin
  pcPages.PageIndex:=0;
  uDatabase.StartupStorage;

  txtUserName.Text:=uStorage.Header.Username;
  txtPassword.Text:=uStorage.Header.Password;
  txtHostName.Text:=uStorage.Header.HostName;
  txtDataSource.Text:=uStorage.Header.Schema;

  uStorage.Module.hThreadID:=GetCurrentThreadID;
  uStorage.Module.hWindow:=Handle;
  uStorage.Module.OnException:=@OnDBException;
  uStorage.Header.OnConnected:=@OnDBConnected;
  uStorage.Header.OnDisconnected:=@OnDBDisconnected;

  uDatabase.InitializeDBMS(@uStorage.Header,@uStorage.Module);
end;

procedure TLoginForm.pnlLogoClick(Sender: TObject);
begin

end;

procedure TLoginForm.OnDBException(sModule,sLocation,sMessage:string);
begin
  frmException.ShowException(sModule,sLocation,sMessage);
end;

procedure TLoginForm.rgDriversClick(Sender: TObject);
begin
  Header.Mode:=TDBMode(rgDrivers.ItemIndex);
  uStorage.SaveINIFile;
end;

initialization
  {$I frmLogin.lrs}

end.

